Match

Struct Match 

pub struct Match<'a> { /* private fields */ }
A single match within a haystack.

Returned by RegexBuf::find_at and yielded by Matches. The byte offsets start and end index into the original haystack passed to the search call.

Implementations

Source

impl<'a> Match<'a>

pub fn start(&self) -> usize

Byte offset of the first byte of the match within the haystack.

pub fn end(&self) -> usize

Byte offset one past the last byte of the match within the haystack.

For a zero-length match (e.g. $ at end of string) end == start.

pub fn as_bytes(&self) -> &'a [u8]

The matched bytes as a slice of the original haystack.